==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/BaseToolboxType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.schema.ParameterInterface;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p644063_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p831178_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The base type for all Toolbox webservice operations.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for BaseToolboxType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="BaseToolboxType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BaseToolboxType")
@XmlSeeAlso({
    CompressType.class,
    AttachmentType.class,
    AnnotationType.class,
    SplitType.class,
    MergeType.class,
    SecurityType.class,
    ImageType.class,
    DescriptionType.class,
    RotateType.class,
    OptionsType.class,
    FormsType.class,
    WatermarkType.class,
    ExtractionType.class,
    XmpType.class,
    PrintType.class,
    DeleteType.class,
    MoveType.class,
    OutlineType.class,
    RedactType.class,
    PortfolioType.class,
    ScaleType.class,
    TranscribeType.class
})
public class BaseToolboxType implements ParameterInterface
{


}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/BaseToolboxType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.schema.ParameterInterface;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p689949_="https://jakarta.ee/xml/ns/jaxb" xmlns:p832256_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The base type for all Toolbox webservice operations.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for BaseToolboxType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="BaseToolboxType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BaseToolboxType")
@XmlSeeAlso({
    CompressType.class,
    AttachmentType.class,
    AnnotationType.class,
    SplitType.class,
    MergeType.class,
    SecurityType.class,
    ImageType.class,
    DescriptionType.class,
    RotateType.class,
    OptionsType.class,
    FormsType.class,
    WatermarkType.class,
    ExtractionType.class,
    XmpType.class,
    PrintType.class,
    DeleteType.class,
    MoveType.class,
    OutlineType.class,
    RedactType.class,
    PortfolioType.class,
    ScaleType.class,
    TranscribeType.class
})
public class BaseToolboxType implements ParameterInterface
{


}
